@@ -49,8 +49,6 @@ class App(cmd2.Cmd):
 
         def serial_configuration() -> bool:
 
-            #if args.connection_serial_port is None:
-
             port = self.nucleus_driver.connection.select_serial_port()
 
             if port is None:
@@ -62,8 +60,6 @@ class App(cmd2.Cmd):
 
         def tcp_configuration() -> bool:
 
-            #if args.connection_tcp_host is None:
-
             self.nucleus_driver.messages.write_message('\nConnect through TCP with host(hostname/ip) or serial number: ')
             self.nucleus_driver.messages.write_message('[0] Host')
             self.nucleus_driver.messages.write_message('[1] Serial_number')
@@ -148,11 +144,7 @@ class App(cmd2.Cmd):
             return
 
         if path is not None:
-            if os.access(path, os.W_OK):
-                self.nucleus_driver.set_log_path(path=path)
-            else:
-                self.nucleus_driver.messages.write_warning('You do not have writing access to specified path')
-                return
+            self.nucleus_driver.set_log_path(path=path)
 
         self.nucleus_driver.start_logging()
         self.nucleus_driver.start_measurement()
@@ -175,11 +167,7 @@ class App(cmd2.Cmd):
             return
 
         if path is not None:
-            if os.access(path, os.W_OK):
-                self.nucleus_driver.set_log_path(path=path)
-            else:
-                self.nucleus_driver.messages.write_warning('You do not have writing access to specified path')
-                return
+            self.nucleus_driver.set_log_path(path=path)
 
         self.nucleus_driver.start_logging()
         self.nucleus_driver.start_fieldcal()
